==> nextcloud-app-news-1%3A25.1.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/news/l10n/el.js <==
OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "Το αίτημα απέτυχε, η σύνδεση στο δίκτυο δεν είναι διαθέσιμη!",
    "Request unauthorized. Are you logged in?" : "Το αίτημα δεν είναι εξουσιοδοτημένο. Είστε συνδεδεμένοι;",
    "Token expired or app not enabled! Reload the page!" : "Η διαδικασία αναγνώρισης τερματίστηκε ή η εφαρμογή δεν είναι ενεργοποιημένη! Επαναφορτώστε τη σελίδα! ",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Εσωτερικό σφάλμα διακομιστή! Παρακαλώ ελέγξτε το αρχείο data/nextcloud.log για περισσότερες πληροφορίες!",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "Αποτυχία αιτήματος, το Nextcloud είναι προσωρινά σε κατάσταση συντήρησης!",
    "Unread articles" : "Μη αναγνωσμένα άρθρα",
    "News" : "Νέα",
    "Shared with me" : "Διαμοιρασμένα με εμένα",
    "An RSS/Atom feed reader" : "Τροφοδότης ροής RSS/Atom",
    "Download" : "Λήψη",
    "Close" : "Κλείσιμο",
    "Web address" : "Διεύθυνση ιστοσελίδας",
    "No folder" : "Κανένας φάκελος",
    "Folder name" : "Όνομα φακέλου",
    "Username" : "Όνομα χρήστη",
    "Password" : "Κωδικός πρόσβασης",
    "Feed exists already!" : "Η ροή υπάρχει ήδη!",
    "New folder" : "Νέος φάκελος",
    "Folder exists already!" : "Ο φάκελος υπάρχει ήδη!",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "Τα διαπιστευτήρια Βασικής Πιστοποίησης HTTP πρέπει να αποθηκεύονται χωρίς κρυπτογράφηση! Όλοι με πρόσβαση στον διακομιστή ή τη βάση δεδομένων θα έχουν πρόσβαση σε αυτά!",
    "Credentials" : "Πιστοποιητικά",
    "Subscribe" : "Εγγραφή",
    "Maximum read count per feed" : "Ο μέγιστος αριθμός διαβασμένων ανά ροή",
    "Maximum redirects" : "Μέγιστος αριθμός ανακατευθύνσεων",
    "Feed fetcher timeout" : "Χρόνος λήξης δέκτη ροής",
    "Explore Service URL" : "URL Υπηρεσίας Εξερεύνησης",
    "Update interval" : "Εσωτερική ενημέρωση",
    "Use system cron for updates" : "Χρήση του cron του συστήματος για ενημερώσεις",
    "How many redirects the feed fetcher should follow." : "Πόσες ανακατευθύνσεις θα μπορεί να ακολουθεί η υπηρεσία ροών.",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Μέγιστος χρόνος σε δευτερόλεπτα, αναμονής φόρτωσης μιας ροής RSS ή Atom; εάν χρειαστεί περισσότερο χρόνο η ενημέρωση θα ματαιωθεί.",
    "Interval in seconds in which the feeds will be updated." : "Διάστημα σε δευτερόλεπτα στο οποίο θα ενημερωθούν τα feeds.",
    "Move" : "Μετακίνηση",
    "Share" : "Διαμοιρασμός",
    "Share with" : "Διαμοιρασμός με",
    "Mark read" : "Σημείωση ως ανεγνωσμένου",
    "All articles" : "Όλα τα άρθρα",
    "Starred" : "Με αστέρι",
    "Explore" : "Εξερεύνηση",
    "Settings" : "Ρυθμίσεις",
    "Keyboard shortcuts" : "Συντομεύσεις πλητρολογίου",
    "Disable mark read through scrolling" : "Απενεργοποίηση σημείωσης ως διαβασμένων κατά τη κύλιση",
    "Compact view" : "Συμπαγής προβολή",
    "Show all articles" : "Εμφάνιση όλων των άρθρων",
    "Reverse ordering (oldest on top)" : "Ανεστραμμένη ταξινόμηση (παλαιότερα στην κορυφή)",
    "Rename" : "Μετονομασία",
    "Delete" : "Διαγραφή",
    "Rename Feed" : "Μετονομασία Ροής",
    "Unpin from top" : "Ξεκαρφίτσωμα από την κορυφή",
    "Pin to top" : "Καρφίτσωμα στην κορυφή",
    "Newest first" : "Νεότερο πρώτα",
    "Oldest first" : "Παλαιότερο πρώτα",
    "Default order" : "Προεπιλεγμένη σειρά",
    "Enable full text" : "Ενεργοποίηση πλήρους κειμένου",
    "Disable full text" : "Απενεργοποίηση πλήρους κειμένου",
    "Unread updated" : "Μη αναγνωσμένο ενημερώθηκε",
    "Ignore updated" : "Αγνόηση ενημέρωσης",
    "Toggle star article" : "Εναλλαγή επισήμανσης άρθρου με αστέρι",
    "Mark unread" : "σημειώστε ως μη αναγνωσμένο",
    "Close details" : "Κλείσιμο λεπτομερειών",
    "by" : "από",
    "from" : "από",
    "shared by" : "σε κοινή χρήση από",
    "Play audio" : "Αναπαραγωγή ήχου",
    "Download audio" : "Λήψη ήχου",
    "Download video" : "Κατεβάστε το βίντεο",
    "Open website" : "Άνοιγμα ιστοσελίδας",
    "Keep article unread" : "Διατήρηση άρθρου ως μη αναγνωσμένου",
    "Toggle keep current article unread" : "Εναλλαγή διατήρισης τρέχοντος άρθρου ως μη αναγνωσμένου",
    "Remove keep article unread" : "Αφαίρεση διατήρησης άρθρου ως μη αναγνωσμένου",
    "Keyboard shortcut" : "Συντόμευση πλητρολογίου",
    "Action" : "Ενέργεια",
    "right" : "δεξιά",
    "Jump to next article" : "Επόμενο άρθρο",
    "left" : "αριστερά",
    "Jump to previous article" : "Προηγούμενο άρθρο",
    "Star article and jump to next one" : "Επισήμανση άρθρου και μετακίνηση στο επόμενο",
    "Open article in new tab" : "Άνοιγμα άρθρου σε νέα καρτέλα",
    "Refresh" : "Ανανέωση ",
    "Load next feed" : "Φόρτωση επόμενης ροής",
    "Load previous feed" : "Φόρτωση προηγούμενης ροής",
    "Load previous folder" : "Φόρτωση προηγούμενου φακέλου",
    "Load next folder" : "Φόρτωση επόμενου φακέλου",
    "Scroll to active navigation entry" : "Κύλιση στην ενεργή είσοδο πλοήγησης ",
    "Shift" : "Shift",
    "Subscribe to" : "Εγγραφείτε στο",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax ή webcron κατάσταση εντοπίστηκε! Οι ροές σας δεν θα ενημερωθούν!",
    "How to set up the operating system cron" : "Πώς να ρυθμίσετε την υπηρεσία cron του λειτουργικού συστήματος",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Εγκαταστήστε και ρυθμίστε μιά παράλληλη γρηγορότερη ενημέρωση που χρησιμοποιεί το ΑΡΙ ενημέρωσης της εφαρμογής Νέα",
    "No articles available" : "Δεν υπάρχουν διαθέσιμα άρθρα",
    "No unread articles available" : "Κανένα αδιάβαστο άρθρο διαθέσιμο",
    "Star article" : "Επισήμανση με αστέρι",
    "Unstar article" : "Αναίρεση επισήμανσης με αστέρι",
    "No users found" : "Δεν βρέθηκαν χρήστες",
    "Share on social media" : "Κοινοποίηση στα μέσα κοινωνικής δικτύωσης",
    "Description" : "Περιγραφή",
    "Toggle expand article in compact view" : "Εναλλαγή επέκτασης άρθρου στη συμπαγή προβολή",
    "Mark current article's feed/folder read" : "Σημείωση της ροής/φακέλου του τρέχοντος άρθρου ως αναγνωσμένα",
    "Folder" : "Φάκελος",
    "Go back" : "Μετακίνηση πίσω",
    "New Folder" : "Νέος φάκελος",
    "Create" : "Δημιουργία",
    "Update failed more than 50 times" : "Η αποστολή απέτυχε πάνω από 50 φορές",
    "Deleted feed" : "Διαγραφή ροής",
    "Undo delete feed" : "Αναίρεση διαγραφής ροής",
    "Menu" : "Μενού",
    "Open feed URL" : "Ανοίξτε τη διεύθυνση URL ροής",
    "Dismiss" : "Αποδέσμευση",
    "Collapse" : "Σύμπτυξη",
    "Deleted folder" : "Διαγραφή φακέλου",
    "Undo delete folder" : "Αναίρεση διαγραφής φακέλου",
    "Expand articles on key navigation" : "Ανάπτυξη των άρθρων κατά την πλοήγηση με πλήκτρα",
    "Subscriptions (OPML)" : "Συνδρομές (OPML)",
    "Import" : "Εισαγωγή",
    "Export" : "Εξαγωγή",
    "Error when importing: File does not contain valid OPML" : "Σφάλμα κατά την εισαγωγή: Το αρχείο δεν περιέχει έγκυρο OPML",
    "Error when importing: OPML is does neither contain feeds nor folders" : "Σφάλμα εισαγωγής: Το OPML δεν περιέχει ούτε τροφοδοσίες ούτε φακέλους",
    "Unread/Starred Articles" : "Με αστέρι/Μη αναγνωσμένα Άρθρα",
    "Error when importing: file does not contain valid JSON" : "Σφάλμα κατά την εισαγωγή: το αρχείο δεν περιέχει έγκυρο JSON",
    "Help" : "Βοήθεια",
    "Documentation" : "Τεκμηρίωση",
    "Report a bug" : "Αναφορά σφάλματος"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-news-1%3A25.2.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/news/l10n/el.js <==
OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "Το αίτημα απέτυχε, η σύνδεση στο δίκτυο δεν είναι διαθέσιμη!",
    "Request unauthorized. Are you logged in?" : "Το αίτημα δεν είναι εξουσιοδοτημένο. Είστε συνδεδεμένοι;",
    "Token expired or app not enabled! Reload the page!" : "Η διαδικασία αναγνώρισης τερματίστηκε ή η εφαρμογή δεν είναι ενεργοποιημένη! Επαναφορτώστε τη σελίδα! ",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Εσωτερικό σφάλμα διακομιστή! Παρακαλώ ελέγξτε το αρχείο data/nextcloud.log για περισσότερες πληροφορίες!",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "Αποτυχία αιτήματος, το Nextcloud είναι προσωρινά σε κατάσταση συντήρησης!",
    "Unread articles" : "Μη αναγνωσμένα άρθρα",
    "News" : "Νέα",
    "Shared with me" : "Διαμοιρασμένα με εμένα",
    "An RSS/Atom feed reader" : "Τροφοδότης ροής RSS/Atom",
    "Download" : "Λήψη",
    "Close" : "Κλείσιμο",
    "Web address" : "Διεύθυνση ιστοσελίδας",
    "No folder" : "Κανένας φάκελος",
    "Folder name" : "Όνομα φακέλου",
    "Username" : "Όνομα χρήστη",
    "Password" : "Κωδικός πρόσβασης",
    "Feed exists already!" : "Η ροή υπάρχει ήδη!",
    "New folder" : "Νέος φάκελος",
    "Folder exists already!" : "Ο φάκελος υπάρχει ήδη!",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "Τα διαπιστευτήρια Βασικής Πιστοποίησης HTTP πρέπει να αποθηκεύονται χωρίς κρυπτογράφηση! Όλοι με πρόσβαση στον διακομιστή ή τη βάση δεδομένων θα έχουν πρόσβαση σε αυτά!",
    "Credentials" : "Πιστοποιητικά",
    "Subscribe" : "Εγγραφή",
    "Maximum read count per feed" : "Ο μέγιστος αριθμός διαβασμένων ανά ροή",
    "Maximum redirects" : "Μέγιστος αριθμός ανακατευθύνσεων",
    "Feed fetcher timeout" : "Χρόνος λήξης δέκτη ροής",
    "Explore Service URL" : "URL Υπηρεσίας Εξερεύνησης",
    "Update interval" : "Εσωτερική ενημέρωση",
    "Use system cron for updates" : "Χρήση του cron του συστήματος για ενημερώσεις",
    "How many redirects the feed fetcher should follow." : "Πόσες ανακατευθύνσεις θα μπορεί να ακολουθεί η υπηρεσία ροών.",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Μέγιστος χρόνος σε δευτερόλεπτα, αναμονής φόρτωσης μιας ροής RSS ή Atom; εάν χρειαστεί περισσότερο χρόνο η ενημέρωση θα ματαιωθεί.",
    "Interval in seconds in which the feeds will be updated." : "Διάστημα σε δευτερόλεπτα στο οποίο θα ενημερωθούν τα feeds.",
    "Move" : "Μετακίνηση",
    "Share" : "Διαμοιρασμός",
    "Share with" : "Διαμοιρασμός με",
    "Mark read" : "Σημείωση ως ανεγνωσμένου",
    "All articles" : "Όλα τα άρθρα",
    "Starred" : "Με αστέρι",
    "Explore" : "Εξερεύνηση",
    "Settings" : "Ρυθμίσεις",
    "Documentation" : "Τεκμηρίωση",
    "Keyboard shortcuts" : "Συντομεύσεις πλητρολογίου",
    "Disable mark read through scrolling" : "Απενεργοποίηση σημείωσης ως διαβασμένων κατά τη κύλιση",
    "Show all articles" : "Εμφάνιση όλων των άρθρων",
    "Reverse ordering (oldest on top)" : "Ανεστραμμένη ταξινόμηση (παλαιότερα στην κορυφή)",
    "Default" : "Προεπιλογή",
    "Vertical" : "Κάθετα",
    "Rename" : "Μετονομασία",
    "Delete" : "Διαγραφή",
    "Rename Feed" : "Μετονομασία Ροής",
    "Unpin from top" : "Ξεκαρφίτσωμα από την κορυφή",
    "Pin to top" : "Καρφίτσωμα στην κορυφή",
    "Newest first" : "Νεότερο πρώτα",
    "Oldest first" : "Παλαιότερο πρώτα",
    "Default order" : "Προεπιλεγμένη σειρά",
    "Enable full text" : "Ενεργοποίηση πλήρους κειμένου",
    "Disable full text" : "Απενεργοποίηση πλήρους κειμένου",
    "Unread updated" : "Μη αναγνωσμένο ενημερώθηκε",
    "Ignore updated" : "Αγνόηση ενημέρωσης",
    "Previous" : "Προηγούμενο",
    "Next" : "Επόμενο",
    "Toggle star article" : "Εναλλαγή επισήμανσης άρθρου με αστέρι",
    "Mark unread" : "σημειώστε ως μη αναγνωσμένο",
    "Close details" : "Κλείσιμο λεπτομερειών",
    "by" : "από",
    "from" : "από",
    "shared by" : "σε κοινή χρήση από",
    "Play audio" : "Αναπαραγωγή ήχου",
    "Download audio" : "Λήψη ήχου",
    "Download video" : "Κατεβάστε το βίντεο",
    "Open website" : "Άνοιγμα ιστοσελίδας",
    "Keep article unread" : "Διατήρηση άρθρου ως μη αναγνωσμένου",
    "Toggle keep current article unread" : "Εναλλαγή διατήρισης τρέχοντος άρθρου ως μη αναγνωσμένου",
    "Remove keep article unread" : "Αφαίρεση διατήρησης άρθρου ως μη αναγνωσμένου",
    "Last update" : "Τελευταία ενημέρωση",
    "Title" : "Τίτλος",
    "Keyboard shortcut" : "Συντόμευση πλητρολογίου",
    "Action" : "Ενέργεια",
    "Jump to next article" : "Επόμενο άρθρο",
    "Jump to previous article" : "Προηγούμενο άρθρο",
    "right" : "δεξιά",
    "left" : "αριστερά",
    "Star article and jump to next one" : "Επισήμανση άρθρου και μετακίνηση στο επόμενο",
    "Open article in new tab" : "Άνοιγμα άρθρου σε νέα καρτέλα",
    "Refresh" : "Ανανέωση ",
    "Load next feed" : "Φόρτωση επόμενης ροής",
    "Load previous feed" : "Φόρτωση προηγούμενης ροής",
    "Load previous folder" : "Φόρτωση προηγούμενου φακέλου",
    "Load next folder" : "Φόρτωση επόμενου φακέλου",
    "Scroll to active navigation entry" : "Κύλιση στην ενεργή είσοδο πλοήγησης ",
    "Shift" : "Shift",
    "Subscribe to" : "Εγγραφείτε στο",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax ή webcron κατάσταση εντοπίστηκε! Οι ροές σας δεν θα ενημερωθούν!",
    "How to set up the operating system cron" : "Πώς να ρυθμίσετε την υπηρεσία cron του λειτουργικού συστήματος",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Εγκαταστήστε και ρυθμίστε μιά παράλληλη γρηγορότερη ενημέρωση που χρησιμοποιεί το ΑΡΙ ενημέρωσης της εφαρμογής Νέα",
    "No articles available" : "Δεν υπάρχουν διαθέσιμα άρθρα",
    "No unread articles available" : "Κανένα αδιάβαστο άρθρο διαθέσιμο",
    "Star article" : "Επισήμανση με αστέρι",
    "Unstar article" : "Αναίρεση επισήμανσης με αστέρι",
    "No users found" : "Δεν βρέθηκαν χρήστες",
    "Share on social media" : "Κοινοποίηση στα μέσα κοινωνικής δικτύωσης",
    "Description" : "Περιγραφή",
    "Toggle expand article in compact view" : "Εναλλαγή επέκτασης άρθρου στη συμπαγή προβολή",
    "Mark current article's feed/folder read" : "Σημείωση της ροής/φακέλου του τρέχοντος άρθρου ως αναγνωσμένα",
    "Folder" : "Φάκελος",
    "Go back" : "Μετακίνηση πίσω",
    "New Folder" : "Νέος φάκελος",
    "Create" : "Δημιουργία",
    "Update failed more than 50 times" : "Η αποστολή απέτυχε πάνω από 50 φορές",
    "Deleted feed" : "Διαγραφή ροής",
    "Undo delete feed" : "Αναίρεση διαγραφής ροής",
    "Menu" : "Μενού",
    "Open feed URL" : "Ανοίξτε τη διεύθυνση URL ροής",
    "Dismiss" : "Αποδέσμευση",
    "Collapse" : "Σύμπτυξη",
    "Deleted folder" : "Διαγραφή φακέλου",
    "Undo delete folder" : "Αναίρεση διαγραφής φακέλου",
    "Compact view" : "Συμπαγής προβολή",
    "Expand articles on key navigation" : "Ανάπτυξη των άρθρων κατά την πλοήγηση με πλήκτρα",
    "Subscriptions (OPML)" : "Συνδρομές (OPML)",
    "Import" : "Εισαγωγή",
    "Export" : "Εξαγωγή",
    "Error when importing: File does not contain valid OPML" : "Σφάλμα κατά την εισαγωγή: Το αρχείο δεν περιέχει έγκυρο OPML",
    "Error when importing: OPML is does neither contain feeds nor folders" : "Σφάλμα εισαγωγής: Το OPML δεν περιέχει ούτε τροφοδοσίες ούτε φακέλους",
    "Unread/Starred Articles" : "Με αστέρι/Μη αναγνωσμένα Άρθρα",
    "Error when importing: file does not contain valid JSON" : "Σφάλμα κατά την εισαγωγή: το αρχείο δεν περιέχει έγκυρο JSON",
    "Help" : "Βοήθεια",
    "Report a bug" : "Αναφορά σφάλματος"
},
"nplurals=2; plural=(n != 1);");
